@@ -21,151 +21,133 @@
     </message>
 </context>
 <context>
-    <name>setting</name>
+    <name>Setting</name>
     <message>
-        <location filename="../qml/setting.qml" line="143"/>
-        <location filename="../qml/setting.qml" line="209"/>
-        <source>BaiduOCR</source>
-        <translation>百度文字识别服务</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="222"/>
-        <location filename="../qml/setting.qml" line="351"/>
-        <source>APP_ID</source>
-        <translation>APP_ID</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="234"/>
-        <location filename="../qml/setting.qml" line="392"/>
-        <source>API_KEY</source>
-        <translation>API_KEY</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="246"/>
-        <source>SECRET_KEY</source>
-        <translation>SECRET_KEY</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="258"/>
-        <source>Languages</source>
-        <translation>语言</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="11"/>
-        <source>FastOCR Setting</source>
-        <translation>FastOCR 设置</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="31"/>
-        <source>Save</source>
-        <translation>保存</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="68"/>
-        <source>Apply</source>
-        <translation>应用</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="103"/>
-        <source>Close</source>
-        <translation>关闭</translation>
-    </message>
-    <message>
-        <location filename="../qml/setting.qml" line="128"/>
         <source>Default backend</source>
         <translation>默认后端</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="152"/>
-        <location filename="../qml/setting.qml" line="338"/>
+        <source>BaiduOCR</source>
+        <translation>百度文字识别服务</translation>
+    </message>
+    <message>
         <source>YoudaoOCR</source>
         <translation>有道 OCR 识别服务</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="161"/>
-        <location filename="../qml/setting.qml" line="379"/>
         <source>Face++OCR</source>
         <translation>Face++ OCR 识别服务</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="167"/>
         <source>Icon theme</source>
         <translation>图标主题</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="178"/>
         <source>Auto Select</source>
         <translation>自动</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="179"/>
         <source>Light</source>
         <translation>亮色</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="180"/>
         <source>Dark</source>
         <translation>暗色</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="187"/>
         <source>Working mode</source>
         <translation>工作模式</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="198"/>
         <source>Copy to clipboard</source>
         <translation>复制到系统剪贴板</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="199"/>
         <source>Show notification only</source>
         <translation>仅显示通知</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="271"/>
+        <source>APP_ID</source>
+        <translation>APP_ID</translation>
+    </message>
+    <message>
+        <source>API_KEY</source>
+        <translation>API_KEY</translation>
+    </message>
+    <message>
+        <source>SECRET_KEY</source>
+        <translation>SECRET_KEY</translation>
+    </message>
+    <message>
+        <source>Languages</source>
+        <translation>语言</translation>
+    </message>
+    <message>
         <source>Japanese</source>
         <translation>日语</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="280"/>
         <source>Korean</source>
         <translation>韩语</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="289"/>
         <source>French</source>
         <translation>法语</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="298"/>
         <source>Spanish</source>
         <translation>西班牙语</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="307"/>
         <source>Germany</source>
         <translation>德语</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="316"/>
         <source>Russian</source>
         <translation>俄语</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="325"/>
         <source>Use accurate mode</source>
         <translation>使用高精度模式</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="363"/>
         <source>SEC_KEY</source>
         <translation>SEC_KEY</translation>
     </message>
     <message>
-        <location filename="../qml/setting.qml" line="404"/>
         <source>API_SEC</source>
         <translation>API_SEC</translation>
     </message>
+    <message>
+        <source>Save</source>
+        <translation>保存</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>应用</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>关闭</translation>
+    </message>
+    <message>
+        <source>Open in editor</source>
+        <translation>手动编辑</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <source>FastOCR Setting</source>
+        <translation>FastOCR 设置</translation>
+    </message>
+    <message>
+        <source>Setting</source>
+        <translation>设置</translation>
+    </message>
+    <message>
+        <source>About</source>
+        <translation>关于</translation>
+    </message>
 </context>
 </TS>
