@@ -1,46 +1,57 @@
+import json
 from base64 import b64encode
 from hashlib import sha256
 from time import time
 from typing import List
 from uuid import uuid1
 
-from aiohttp import ClientSession
-
 from fastocr.base import BaseOcr
+from fastocr.consts import APP_CACHE_DIR
 from fastocr.setting import Setting
-from fastocr.util import Singleton
 
 
 class BaiduOcr(BaseOcr):
+    TOKEN_FILE = APP_CACHE_DIR / 'baidu_token_data.json'
     API_BASE = 'https://aip.baidubce.com/rest/2.0/ocr/v1'
     AUTH_BASE = 'https://aip.baidubce.com/oauth/2.0/token'
 
     def __init__(self, setting: Setting):
-        self._token = ''
-        self.appid = setting.get('BaiduOCR', 'app_id')
-        self.apikey = setting.get('BaiduOCR', 'api_key')
-        self.seckey = setting.get('BaiduOCR', 'secret_key')
-        self.use_accurate_mode = setting.get_boolean('BaiduOCR', 'use_accurate_mode')
-        self.session = ClientSession()
+        super().__init__()
+        self.appid = setting.baidu_appid
+        self.apikey = setting.baidu_apikey
+        self.seckey = setting.baidu_seckey
+        self.use_accurate_mode = setting.baidu_accurate
 
     @property
     async def token(self):
-        if self._token == '':
-            token, _ = await self.get_token()
-            self._token = token
-        return self._token
+        if self.TOKEN_FILE.exists():
+            with self.TOKEN_FILE.open('r') as f:
+                token_data = json.load(f)
+            expires_in = token_data.get('expires_in', 0)
+            timestamp = token_data.get('timestamp', 0)
+            if time() < timestamp + expires_in:
+                return token_data.get('token', '')
+        token, expires_in = await self.get_token()
+        timestamp = int(time())
+        if expires_in:
+            with self.TOKEN_FILE.open('w') as f:
+                json.dump({
+                    'token': token,
+                    'expires_in': expires_in,
+                    'timestamp': timestamp
+                }, f)
+        return token
 
     async def get_token(self):
         async with self.session.post(
                 f'{self.AUTH_BASE}?grant_type=client_credentials&client_id={self.apikey}&client_secret={self.seckey}') as r:
             data = await r.json()
+            if data.get('error_code') is not None:
+                raise Exception(f"{data.get('error_code')}: {data.get('error_msg')}")
             return data.get('access_token'), data.get('expires_in')
 
     async def basic_general(self, image: bytes, lang='') -> List[str]:
-        if self.use_accurate_mode:
-            api_type = '/accurate_basic'
-        else:
-            api_type = '/general_basic'
+        api_type = '/accurate_basic' if self.use_accurate_mode else '/general_basic'
         data = {
             'image': b64encode(image).decode(),
             'language_type': lang if lang != '' else 'CHN_ENG'
@@ -60,11 +71,12 @@ class YoudaoOcr(BaseOcr):
     SALT = str(uuid1())
 
     def __init__(self, setting: Setting):
+        super().__init__()
         self.appid = setting.get('YoudaoOCR', 'app_id')  # appKey in Youdao docs
         self.seckey = setting.get('YoudaoOCR', 'secret_key')  # appSecret in Youdao docs
-        self.session = ClientSession()
 
-    def truncate(self, image: bytes):
+    @staticmethod
+    def truncate(image: bytes):
         q = b64encode(image).decode()
         q_size = len(q)
         if q is None:
@@ -106,20 +118,58 @@ class YoudaoOcr(BaseOcr):
         await self.session.close()
 
 
+class FaceOcr(BaseOcr):
+    API_BASE = 'https://api-cn.faceplusplus.com'
+    MIN_SIZE = 48
+    MAX_SIZE = 800
+
+    def __init__(self, setting: Setting):
+        super().__init__()
+        self.apikey = setting.face_apikey
+        self.apisec = setting.face_apisec
+
+    async def basic_general(self, image: bytes, lang='') -> List[str]:
+        data = {
+            'api_key': self.apikey,
+            'api_secret': self.apisec,
+            'image_base64': b64encode(image).decode()
+        }
+        async with self.session.post(f'{self.API_BASE}/imagepp/v1/recognizetext', data=data) as r:
+            res = await r.json()
+            if res.get('error_message'):
+                raise Exception(res.get('error_message', ''))
+            result = filter(lambda x: x.get('type') == 'textline', res.get('result', []))
+            return [r.get('value', '') for r in result]
+
+    async def close(self):
+        await self.session.close()
+
+
 BACKENDS = {
     'baidu': BaiduOcr,
-    'youdao': YoudaoOcr
+    'youdao': YoudaoOcr,
+    'face': FaceOcr,
 }
 
 
-class OcrService(metaclass=Singleton):
+class OcrService:
     def __init__(self, backend: str = 'baidu'):
         backend_class = BACKENDS.get(backend)
         if not backend_class:
             raise Exception(f'{backend} 后端不存在')
         self.setting = Setting()
+        self.setting.reload()
         self.backend = backend_class(self.setting)
 
+    def image_scaling(self) -> tuple:
+        min_size = 0
+        max_size = 0
+        if hasattr(self.backend, 'MIN_SIZE'):
+            min_size = getattr(self.backend, 'MIN_SIZE')
+        if hasattr(self.backend, 'MAX_SIZE'):
+            max_size = getattr(self.backend, 'MAX_SIZE')
+        return min_size, max_size
+
     async def close(self):
         await self.backend.close()
 
